@@ -28,9 +28,14 @@ class Literal:
 
 @dataclass(frozen=True)
 class GroupConstraint:
+    """Represents a group of constraints."""
+
     joiner: str
     constraints: List[Union["GroupConstraint", BinaryConstraint]]
 
+    def add(self, constraint: Union["GroupConstraint", BinaryConstraint]):
+        self.constraints.append(constraint)
+
 
 Constraints = Union[
     BinaryConstraint,
