@@ -8,8 +8,8 @@ from asyncpg.transaction import Transaction
 
 import apgw.builder as builder
 from apgw.constraint import Constraints
-from apgw.types import (ConnectionArgs, InsertAssignments, LimitOffset, Record,
-                        RecordsAndCount)
+from apgw.types import (ConnectArgs, ConnectionArgs, InsertAssignments,
+                        LimitOffset, Record, RecordsAndCount)
 
 
 class DBBase:
@@ -58,8 +58,10 @@ class DBBase:
         self.logger = logger
         return self
 
-    def set_connect(self, connect: Callable[..., Connection]) -> "DBBase":
-        self.connect = connect
+    def set_connect(
+        self, custom_connect: Callable[[ConnectArgs], Connection]
+    ) -> "DBBase":
+        self.connect = custom_connect
         return self
 
     async def get_connection_args(self) -> ConnectionArgs:
