@@ -1,7 +1,8 @@
 """Shared types."""
 from typing import Any, List, Mapping, Optional, Tuple, Union
 
-ConnectionArgs = Union[Mapping[str, Any], str]
+ConnectArgs = Mapping[str, Any]
+ConnectionArgs = Union[ConnectArgs, str]
 
 InsertAssignments = Union[
     Mapping[str, Any],
