@@ -41,8 +41,7 @@ def constraint_list_to_sql(
         else:
             if constraint.operator == "in":
                 in_list = ", ".join(
-                    "${}".format(ph)
-                    for ph in range(placeholder, placeholder + len(constraint.value))
+                    generate_placeholders(len(constraint.value), placeholder)
                 )
                 parts.append(
                     "{} {} ({})".format(
@@ -68,3 +67,7 @@ def constraint_list_to_sql(
         sql = joiner.join(parts)
 
     return (sql, params)
+
+
+def generate_placeholders(count: int, start_at: int = 1) -> List[str]:
+    return ["${}".format(ph + start_at) for ph in range(count)]
